==> molgenis-charts-1.18.0-sources.jar: org/molgenis/charts/BoxPlotChart.java <==
package org.molgenis.charts;

import java.util.ArrayList;
import java.util.List;

import org.molgenis.charts.data.BoxPlotSerie;
import org.molgenis.charts.data.XYDataSerie;

/**
 * A Molgenis Box Plot Chart
 */
public class BoxPlotChart extends AbstractChart
{
	private List<XYDataSerie> xYDataSeries = new ArrayList<XYDataSerie>();
	private List<BoxPlotSerie> boxPlotSeries = new ArrayList<BoxPlotSerie>();
	private List<String> categories = new ArrayList<String>();

	public BoxPlotChart()
	{
		this.setType(MolgenisChartType.BOXPLOT_CHART);
	}
	
	/**
	 * @return the categories
	 */
	public List<String> getCategories()
	{
		return categories;
	}

	/**
	 * @param categories the categories to set
	 */
	public void setCategories(List<String> categories)
	{
		this.categories = categories;
	}



	/**
	 * @return the xYDataSeries
	 */
	public List<XYDataSerie> getxYDataSeries()
	{
		return xYDataSeries;
	}

	/**
	 * @param xYDataSeries the xYDataSeries to set
	 */
	public void setxYDataSeries(List<XYDataSerie> xYDataSeries)
	{
		this.xYDataSeries = xYDataSeries;
	}

	/**
	 * @return the boxPlotSeries
	 */
	public List<BoxPlotSerie> getBoxPlotSeries()
	{
		return boxPlotSeries;
	}

	/**
	 * @param boxPlotSeries the boxPlotSeries to set
	 */
	public void setBoxPlotSeries(List<BoxPlotSerie> boxPlotSeries)
	{
		this.boxPlotSeries = boxPlotSeries;
	}
	
	/**
	 * @param boxPlotSerie the boxPlotSerie to add
	 */
	public void addBoxPlotSerie(BoxPlotSerie boxPlotSerie){
		this.boxPlotSeries.add(boxPlotSerie);
	}
	
	/**
	 * @param xYDataSerie the xYDataSerie to add
	 */
	public void addXYDataSerie(XYDataSerie xYDataSerie){
		this.xYDataSeries.add(xYDataSerie);
	}
}

==> molgenis-charts-2.0.0-sources.jar: org/molgenis/charts/BoxPlotChart.java <==
package org.molgenis.charts;

import org.molgenis.charts.data.BoxPlotSerie;
import org.molgenis.charts.data.XYDataSerie;

import java.util.ArrayList;
import java.util.List;

/**
 * A Molgenis Box Plot Chart
 */
public class BoxPlotChart extends AbstractChart
{
	private List<XYDataSerie> xYDataSeries = new ArrayList<XYDataSerie>();
	private List<BoxPlotSerie> boxPlotSeries = new ArrayList<BoxPlotSerie>();
	private List<String> categories = new ArrayList<String>();

	public BoxPlotChart()
	{
		this.setType(MolgenisChartType.BOXPLOT_CHART);
	}

	/**
	 * @return the categories
	 */
	public List<String> getCategories()
	{
		return categories;
	}

	/**
	 * @param categories the categories to set
	 */
	public void setCategories(List<String> categories)
	{
		this.categories = categories;
	}

	/**
	 * @return the xYDataSeries
	 */
	public List<XYDataSerie> getxYDataSeries()
	{
		return xYDataSeries;
	}

	/**
	 * @param xYDataSeries the xYDataSeries to set
	 */
	public void setxYDataSeries(List<XYDataSerie> xYDataSeries)
	{
		this.xYDataSeries = xYDataSeries;
	}

	/**
	 * @return the boxPlotSeries
	 */
	public List<BoxPlotSerie> getBoxPlotSeries()
	{
		return boxPlotSeries;
	}

	/**
	 * @param boxPlotSeries the boxPlotSeries to set
	 */
	public void setBoxPlotSeries(List<BoxPlotSerie> boxPlotSeries)
	{
		this.boxPlotSeries = boxPlotSeries;
	}

	/**
	 * @param boxPlotSerie the boxPlotSerie to add
	 */
	public void addBoxPlotSerie(BoxPlotSerie boxPlotSerie)
	{
		this.boxPlotSeries.add(boxPlotSerie);
	}

	/**
	 * @param xYDataSerie the xYDataSerie to add
	 */
	public void addXYDataSerie(XYDataSerie xYDataSerie)
	{
		this.xYDataSeries.add(xYDataSerie);
	}
}
